@@ -96,12 +96,9 @@ class FireXBlazeLauncher(TrackingService):
 
         return self.is_ready_for_tasks
 
-    def get_version(self):
-        import firex_blaze
-        return firex_blaze.__version__
 
     def get_pkg_version_info(self) -> PkgVersionInfo:
         import firex_blaze
-        return PkgVersionInfo(pkg=firex_blaze.__package__,
+        return PkgVersionInfo(pkg='firex-blaze',
                               version=firex_blaze.__version__,
                               commit=firex_blaze._version.get_versions()['full-revisionid'])
\ No newline at end of file
